part2

Function part2 

pub fn part2<M>(
    secret_package: SecretPackage<M>,
    round1_packages: &BTreeMap<Identifier<M>, Package<M>>,
) -> Result<(SecretPackage<M>, BTreeMap<Identifier<M>, Package<M>>), Error<M>>
Performs the second part of the distributed key generation protocol for the participant holding the given round1::SecretPackage, given the received round1::Packages received from the other participants.

It returns the round2::SecretPackage that must be kept in memory by the participant for the final step, and the round2::Packages that must be sent to other participants.